<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="zh_CN">
<context>
    <name>CountdownTooltip</name>
    <message>
        <source>Click the tray icon 
or press the shortcut again to stop recording</source>
        <translation>点击托盘图标
或再次按下录屏快捷键停止录制</translation>
    </message>
    <message>
        <source>Do not rotate your screen during recording</source>
        <translation>屏幕录制中请勿旋转屏幕</translation>
    </message>
</context>
<context>
    <name>IconWidget</name>
    <message>
        <source>Screenshot</source>
        <translation>截图</translation>
    </message>
    <message>
        <source>Recording</source>
        <translation>录屏</translation>
    </message>
</context>
<context>
    <name>MainToolWidget</name>
    <message>
        <source>Record</source>
        <translation>录屏</translation>
    </message>
    <message>
        <source>Screenshot</source>
        <translation>截图</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Screen Capture</source>
        <translation>截图录屏</translation>
    </message>
    <message>
        <source>Save failed. Please save it in your home directory.</source>
        <translation>保存失败。请保存在当前用户目录下。</translation>
    </message>
    <message>
        <source>View</source>
        <translation>查看</translation>
    </message>
    <message>
        <source>Screenshot finished</source>
        <translation>截图完成</translation>
    </message>
    <message>
        <source>PNG (*.png);;JPEG (*.jpg *.jpeg);;BMP (*.bmp)</source>
        <translation>PNG (*.png);;JPEG (*.jpg *.jpeg);;BMP (*.bmp)</translation>
    </message>
    <message>
        <source>JPEG (*.jpg *.jpeg);;PNG (*.png);;BMP (*.bmp)</source>
        <translation>JPEG (*.jpg *.jpeg);;PNG (*.png);;BMP (*.bmp)</translation>
    </message>
    <message>
        <source>BMP (*.bmp);;JPEG (*.jpg *.jpeg);;PNG (*.png)</source>
        <translation>BMP (*.bmp);;JPEG (*.jpg *.jpeg);;PNG (*.png)</translation>
    </message>
    <message>
        <source>select-area</source>
        <translation>选择区域</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>保存</translation>
    </message>
    <message>
        <source>Saved to %1</source>
        <translation>图片已保存到%1</translation>
    </message>
    <message>
        <source>Ignore</source>
        <translation>忽略</translation>
    </message>
    <message>
        <source>Clipboard</source>
        <translation>剪贴板</translation>
    </message>
    <message>
        <source>Saving the screen recording file, please wait...</source>
        <translation>正在保存录屏文件，请稍候...</translation>
    </message>
    <message>
        <source>As the window effect is disabled during the process, the recording has to be stopped</source>
        <translation>因在录制过程中关闭了窗口特效，录屏已结束</translation>
    </message>
    <message>
        <source>Screenshot</source>
        <translation>截图</translation>
    </message>
    <message>
        <source>Screenshot failed.</source>
        <translation>截图失败。</translation>
    </message>
    <message>
        <source>Scrollshot</source>
        <translation>滚动截图</translation>
    </message>
    <message>
        <source>Pin Screenshots</source>
        <translation>贴图</translation>
    </message>
    <message>
        <source>deepin-screen-recorder</source>
        <translation>截图录屏</translation>
    </message>
    <message>
        <source>Open Folder</source>
        <translation>打开文件夹</translation>
    </message>
    <message>
        <source>Screenshot finished and copy to clipboard</source>
        <translation>截图完成，文件已复制到剪贴板</translation>
    </message>
</context>
<context>
    <name>MenuController</name>
    <message>
        <source>Undo</source>
        <translation>撤销</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>保存</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>退出</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Pin Screenshots</source>
        <translation>贴图</translation>
    </message>
</context>
<context>
    <name>QuickPanelWidget</name>
    <message>
        <source>Screenshot</source>
        <translation>截图</translation>
    </message>
    <message>
        <source>Record</source>
        <translation>录屏</translation>
    </message>
</context>
<context>
    <name>RecordIconWidget</name>
    <message>
        <source>Screenshot</source>
        <translation>截图</translation>
    </message>
    <message>
        <source>Recording</source>
        <translation>录屏</translation>
    </message>
</context>
<context>
    <name>RecordProcess</name>
    <message>
        <source>View</source>
        <translation>查看</translation>
    </message>
    <message>
        <source>Recording finished</source>
        <translation>录制完毕</translation>
    </message>
    <message>
        <source>Saved to %1</source>
        <translation>文件已保存到%1</translation>
    </message>
    <message>
        <source>Record</source>
        <translation>录屏</translation>
    </message>
    <message>
        <source>Open Folder</source>
        <translation>打开文件夹</translation>
    </message>
</context>
<context>
    <name>Screenshot</name>
    <message>
        <source>Screen Capture will start in %1 seconds</source>
        <translation>截图录屏将在%1秒后启动</translation>
    </message>
</context>
<context>
    <name>ScrollShotTip</name>
    <message>
        <source>Get help.</source>
        <translation>查看帮助</translation>
    </message>
    <message>
        <source>Failed to take a continuous screenshot.</source>
        <translation>无法继续截图，</translation>
    </message>
    <message>
        <source>Reached the bottom of the scroll area</source>
        <translation>已到滚动区域底部</translation>
    </message>
    <message>
        <source>Reached the maximum length</source>
        <translation>已到最大长度</translation>
    </message>
    <message>
        <source>adjust the capture area</source>
        <translation>调整捕捉区域</translation>
    </message>
    <message>
        <source>Scroll your mouse wheel or click to take a scrolling screenshot</source>
        <translation>滚动鼠标滚轮或单击捕捉区域</translation>
    </message>
    <message>
        <source>Slow down the scrolling speed</source>
        <translation>请放慢滚动速度</translation>
    </message>
    <message>
        <source>Invalid area, click to </source>
        <translation>无效区域，点击</translation>
    </message>
</context>
<context>
    <name>ShapesWidget</name>
    <message>
        <source>Input text here</source>
        <translation>在此处添加文本</translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Start/Screenshot</source>
        <translation>启动/截图 </translation>
    </message>
    <message>
        <source>Exit/Save</source>
        <translation>退出/保存</translation>
    </message>
    <message>
        <source>Size Adjustment</source>
        <translation>调整区域</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>设置</translation>
    </message>
    <message>
        <source>Quick start</source>
        <translation>快速启动截图</translation>
    </message>
    <message>
        <source>Window screenshot</source>
        <translation>光标所在窗口截图</translation>
    </message>
    <message>
        <source>Delay screenshot</source>
        <translation>延时5秒截屏</translation>
    </message>
    <message>
        <source>Full screenshot</source>
        <translation>截取全屏</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>退出</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>保存</translation>
    </message>
    <message>
        <source>Rectangle</source>
        <translation>矩形</translation>
    </message>
    <message>
        <source>Ellipse</source>
        <translation>椭圆</translation>
    </message>
    <message>
        <source>Line</source>
        <translation>直线</translation>
    </message>
    <message>
        <source>Pencil</source>
        <translation>画笔</translation>
    </message>
    <message>
        <source>Text</source>
        <translation>文字</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>删除选中图形</translation>
    </message>
    <message>
        <source>Undo</source>
        <translation>撤销</translation>
    </message>
    <message>
        <source>Increase height up</source>
        <translation>向上扩大选区高度</translation>
    </message>
    <message>
        <source>Increase height down</source>
        <translation>向下扩大选区高度</translation>
    </message>
    <message>
        <source>Increase width left</source>
        <translation>向左扩大选区宽度</translation>
    </message>
    <message>
        <source>Increase width right</source>
        <translation>向右扩大选区宽度</translation>
    </message>
    <message>
        <source>Decrease height up</source>
        <translation>向上缩小选区高度</translation>
    </message>
    <message>
        <source>Decrease height down</source>
        <translation>向下缩小选区高度</translation>
    </message>
    <message>
        <source>Decrease width left</source>
        <translation>向左缩小选区宽度</translation>
    </message>
    <message>
        <source>Decrease width right</source>
        <translation>向右缩小选区宽度</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>帮助</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>显示快捷键</translation>
    </message>
    <message>
        <source>Sound</source>
        <translation>录音</translation>
    </message>
    <message>
        <source>Keystroke</source>
        <translation>按键</translation>
    </message>
    <message>
        <source>Webcam</source>
        <translation>摄像头</translation>
    </message>
    <message>
        <source>Start recording</source>
        <translation>快速启动录屏</translation>
    </message>
    <message>
        <source>Options</source>
        <translation>选项</translation>
    </message>
    <message>
        <source>Start/Recording</source>
        <translation>启动/录屏</translation>
    </message>
    <message>
        <source>Mouse</source>
        <translation>录制鼠标</translation>
    </message>
    <message>
        <source>Tools</source>
        <translation>工具</translation>
    </message>
    <message>
        <source>Extract text</source>
        <translation>识别文字</translation>
    </message>
    <message>
        <source>Scrollshot</source>
        <translation>滚动截图</translation>
    </message>
    <message>
        <source>Pin screenshots</source>
        <translation>贴图</translation>
    </message>
    <message>
        <source>Start OCR</source>
        <translation>快速启动图文识别</translation>
    </message>
    <message>
        <source>Start scrollshot</source>
        <translation>启动滚动截图</translation>
    </message>
    <message>
        <source>Arrow</source>
        <translation>箭头</translation>
    </message>
</context>
<context>
    <name>ShotStartPlugin</name>
    <message>
        <source>Screenshot</source>
        <translation>截图</translation>
    </message>
</context>
<context>
    <name>ShotStartRecordPlugin</name>
    <message>
        <source>Record</source>
        <translation>录屏</translation>
    </message>
</context>
<context>
    <name>ShotToolWidget</name>
    <message>
        <source>Rectangle
Press and hold Shift to draw a square</source>
        <translation>矩形
按住Shift可画正方形</translation>
    </message>
    <message>
        <source>Ellipse
Press and hold Shift to draw a circle</source>
        <translation>椭圆
按住Shift可画圆形</translation>
    </message>
    <message>
        <source>Brush
Press and hold Shift to draw a straight line</source>
        <translation>笔刷
按住Shift可画直线</translation>
    </message>
    <message>
        <source>Adjust blur strength (Scroll to adjust it)</source>
        <translation>调整模糊强度（鼠标滚轮）</translation>
    </message>
    <message>
        <source>Adjust brush size (Scroll to adjust it)</source>
        <translation>调整笔刷大小（鼠标滚轮）</translation>
    </message>
    <message>
        <source>Adjust text size (Scroll to adjust it)</source>
        <translation>调整文字大小（鼠标滚轮）</translation>
    </message>
</context>
<context>
    <name>StartTooltip</name>
    <message>
        <source>Click or drag to
select the area to record</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>SubToolWidget</name>
    <message>
        <source>Show keystroke (K)</source>
        <translation>显示按键 K</translation>
    </message>
    <message>
        <source>Hide Keystroke (K)</source>
        <translation>隐藏按键 K</translation>
    </message>
    <message>
        <source>Show Keystroke (K)</source>
        <translation>显示按键 K</translation>
    </message>
    <message>
        <source>Turn on camera (C)</source>
        <translation>开启摄像头 C</translation>
    </message>
    <message>
        <source>Turn off camera (C)</source>
        <translation>关闭摄像头 C</translation>
    </message>
    <message>
        <source>Screenshot</source>
        <translation>截图</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>设置</translation>
    </message>
    <message>
        <source>Settings (F3)</source>
        <translation>设置 F3</translation>
    </message>
    <message>
        <source>Format:</source>
        <translation>格式：</translation>
    </message>
    <message>
        <source>GIF</source>
        <translation>GIF</translation>
    </message>
    <message>
        <source>MP4</source>
        <translation>MP4</translation>
    </message>
    <message>
        <source>MKV</source>
        <translation>MKV</translation>
    </message>
    <message>
        <source>webm</source>
        <translation>webm</translation>
    </message>
    <message>
        <source>FPS:</source>
        <translation>帧数：</translation>
    </message>
    <message>
        <source>5 fps</source>
        <translation>5 fps</translation>
    </message>
    <message>
        <source>10 fps</source>
        <translation>10 fps</translation>
    </message>
    <message>
        <source>20 fps</source>
        <translation>20 fps</translation>
    </message>
    <message>
        <source>24 fps</source>
        <translation>24 fps</translation>
    </message>
    <message>
        <source>30 fps</source>
        <translation>30 fps</translation>
    </message>
    <message>
        <source>Sound</source>
        <translation>声音</translation>
    </message>
    <message>
        <source>Microphone</source>
        <translation>麦克风</translation>
    </message>
    <message>
        <source>System audio</source>
        <translation>系统音频</translation>
    </message>
    <message>
        <source>Options</source>
        <translation>选项</translation>
    </message>
    <message>
        <source>Show pointer</source>
        <translation>显示光标</translation>
    </message>
    <message>
        <source>Show click</source>
        <translation>显示鼠标点击</translation>
    </message>
    <message>
        <source>Save to</source>
        <translation>保存到</translation>
    </message>
    <message>
        <source>Desktop</source>
        <translation>桌面</translation>
    </message>
    <message>
        <source>Videos</source>
        <translation>视频</translation>
    </message>
    <message>
        <source>Rectangle (R)
Press and hold Shift to draw a square</source>
        <translation>矩形（R）
按住Shift可画正方形</translation>
    </message>
    <message>
        <source>Ellipse (O)
Press and hold Shift to draw a circle</source>
        <translation>椭圆（O）
按住Shift可画圆形</translation>
    </message>
    <message>
        <source>Line (L)
Press and hold Shift to draw a vertical or horizontal line</source>
        <translation>直线（L）
按住Shift可画垂直线和水平线</translation>
    </message>
    <message>
        <source>Arrow (X)
Press and hold Shift to draw a vertical or horizontal arrow</source>
        <translation>箭头（X）
按住Shift可画垂直和水平箭头</translation>
    </message>
    <message>
        <source>Pencil (P)</source>
        <translation>画笔 P</translation>
    </message>
    <message>
        <source>Blur (B)</source>
        <translation>模糊 B</translation>
    </message>
    <message>
        <source>Text (T)</source>
        <translation>文字 T</translation>
    </message>
    <message>
        <source>Scrollshot (Alt+I）</source>
        <translation>滚动截图 Alt+I</translation>
    </message>
    <message>
        <source>Extract text (Alt+O）</source>
        <translation>识别文字 Alt+O</translation>
    </message>
    <message>
        <source>Pin screenshots (Alt+P）</source>
        <translation>贴图 Alt+P</translation>
    </message>
    <message>
        <source>Undo (Ctrl+Z)</source>
        <translation>撤销 Ctrl+Z</translation>
    </message>
    <message>
        <source>Record</source>
        <translation>录屏</translation>
    </message>
    <message>
        <source>Clipboard</source>
        <translation>剪贴板</translation>
    </message>
    <message>
        <source>Pictures</source>
        <translation>图片</translation>
    </message>
    <message>
        <source>Folder</source>
        <translation>指定位置</translation>
    </message>
    <message>
        <source>Set a path on save</source>
        <translation>保存时设置位置</translation>
    </message>
    <message>
        <source>Change the path on save</source>
        <translation>保存时更新位置</translation>
    </message>
    <message>
        <source>Format</source>
        <translation>格式</translation>
    </message>
    <message>
        <source>PNG</source>
        <translation>PNG</translation>
    </message>
    <message>
        <source>JPG</source>
        <translation>JPG</translation>
    </message>
    <message>
        <source>BMP</source>
        <translation>BMP</translation>
    </message>
    <message>
        <source>Border Effects</source>
        <translation>边框效果</translation>
    </message>
    <message>
        <source>None</source>
        <translation>无边框</translation>
    </message>
    <message>
        <source>Shadow</source>
        <translation>投影</translation>
    </message>
    <message>
        <source>Border</source>
        <translation>外边框</translation>
    </message>
    <message>
        <source>Device</source>
        <translation>样机</translation>
    </message>
    <message>
        <source>Extract Text</source>
        <translation>识别文字</translation>
    </message>
</context>
<context>
    <name>ToolBarWidget</name>
    <message>
        <source>Close (Esc)</source>
        <translation>关闭 Esc</translation>
    </message>
    <message>
        <source>OK (Enter)</source>
        <translation>确认 Enter</translation>
    </message>
</context>
<context>
    <name>TopTips</name>
    <message>
        <source> Adjust the recording area within %1*%2 to get better video effect</source>
        <translation> 调整录制区域范围在%1*%2以内，视频效果更佳</translation>
    </message>
</context>
<context>
    <name>Utils</name>
    <message>
        <source>Screen recording is not supported at present</source>
        <translation>录屏功能暂不可用</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>退出</translation>
    </message>
</context>
<context>
    <name>VoiceRecordProcess</name>
    <message>
        <source>New recording</source>
        <translation>新录音</translation>
    </message>
</context>
</TS>